#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-class-plugin-2.3.0.0-3COxeXM8qwZsyDsBdPTVs
key:                  hls-class-plugin-2.3.0.0-3COxeXM8qwZsyDsBdPTVs
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e1819fbab474c17544eea5af1c04b49d
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.3.0.0-3COxeXM8qwZsyDsBdPTVs
depends:
    aeson-2.2.1.0-KqVneGNcXEJ8mIL8sTS8LL base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-7J4flVDuVp79ZQl3ULvjo5 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-EjrTaLmfueE8YeSqB1isRU
    ghcide-2.3.0.0-HbBecx74htg70XGZBoVLBG
    hls-graph-2.3.0.0-C0ii0lxGNjwCMvRrwCM0Qd
    hls-plugin-api-2.3.0.0-HYdBIsoiAM91QY4A9avICV
    lens-5.3.4-59xiJiOdHtvHZvlFC0zvFo
    lsp-2.2.0.0-LeT2ktaJdH62xlttOS1KCX mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

